/*
 * debug.c - for debug and logging
 *
 * Copyright (C) 2020 IOPSYS Software Solutions AB. All rights reserved.
 *
 */

#include <stdio.h>
#include <stdint.h>
#include <stdbool.h>
#include <stdarg.h>
#include <syslog.h>
#include <sys/types.h>
#include <unistd.h>
#include <time.h>

#include "debug.h"

extern bool syslogging;
static const int syslog_level[] = { LOG_ERR, LOG_WARNING, LOG_INFO, LOG_DEBUG };

void start_logging(const char *prog)
{
	if (syslogging)
		openlog(prog, 0, LOG_DAEMON);
}

void stop_logging(void)
{
	if (syslogging)
		closelog();
}

void log_message(int level, const char *fmt, ...)
{
	va_list args;
	int max_loglevel = sizeof(syslog_level)/sizeof(syslog_level[0]) - 1;

	va_start(args, fmt);
	if (syslogging && level >= 0) {
		level = (level > max_loglevel) ? max_loglevel : level;
		vsyslog(syslog_level[level], fmt, args);
	}

	va_end(args);
}
